From 6ea11b19ec84384954ef2f108376aa0326ee0d8c Mon Sep 17 00:00:00 2001
From: Loic Devulder <loic.devulder@laposte.net>
Date: Fri, 1 Jul 2016 12:05:50 +0200
Subject: [PATCH] util: add support of GRUB_DEVICETREE_FILE option

As the 'devicetree' option exists in grub, it could be useful to add
them in the grub.cfg configuration file like the 'kernel' or 'initrd'
options.

This commit adds support of GRUB_DEVICETREE_FILE option in
/etc/default/grub file.
---
 util/grub-mkconfig.in       | 3 ++-
 util/grub.d/10_linux.in     | 7 +++++++
 util/grub.d/20_linux_xen.in | 7 +++++++
 3 files changed, 16 insertions(+), 1 deletion(-)

diff --git a/util/grub-mkconfig.in b/util/grub-mkconfig.in
index f8496d2..0dab013 100644
--- a/util/grub-mkconfig.in
+++ b/util/grub-mkconfig.in
@@ -263,6 +263,7 @@
   GRUB_DISABLE_SUBMENU \
   GRUB_CMDLINE_LINUX_RECOVERY \
   GRUB_USE_LINUXEFI \
+  GRUB_DEVICETREE_FILE \
   SUSE_BTRFS_SNAPSHOT_BOOTING \
   SUSE_CMDLINE_XENEFI
 
diff --git a/util/grub.d/10_linux.in b/util/grub.d/10_linux.in
index de9044c..035ea50 100644
--- a/util/grub.d/10_linux.in
+++ b/util/grub.d/10_linux.in
@@ -188,6 +188,13 @@ EOF
 EOF
     fi
   fi
+  if [ -n "${GRUB_DEVICETREE_FILE}" ]; then
+    message="$(gettext_printf "Loading custom devicetree ...")"
+    sed "s/^/$submenu_indentation/" << EOF
+  echo  '$(echo "$message" | grub_quote)'
+  devicetree ${GRUB_DEVICETREE_FILE}
+EOF
+  fi
   sed "s/^/$submenu_indentation/" << EOF
 }
 EOF
diff --git a/util/grub.d/20_linux_xen.in b/util/grub.d/20_linux_xen.in
index c48af94..22d597e 100644
--- a/util/grub.d/20_linux_xen.in
+++ b/util/grub.d/20_linux_xen.in
@@ -212,6 +212,13 @@ EOF
 	module	--nounzip   ${rel_dirname}/${initrd}
 EOF
   fi
+  if [ -n "${GRUB_DEVICETREE_FILE}" ]; then
+    message="$(gettext_printf "Loading custom devicetree ...")"
+    sed "s/^/$submenu_indentation/" << EOF
+  echo  '$(echo "$message" | grub_quote)'
+  devicetree ${GRUB_DEVICETREE_FILE}
+EOF
+  fi
   sed "s/^/$submenu_indentation/" << EOF
 }
 EOF
--
2.8.4

